@@ -32,6 +32,7 @@
 
 #include <stdio.h>
 #include <stdlib.h>
+#include <string.h>
 #include <gtk/gtk.h>
 #include <libgimp/gimp.h>
 #include "gimppluginwindow.h"
@@ -64,7 +65,7 @@ typedef struct {
   GtkWidget *entry;
 
   GtkWidget *preview;
-  GDrawable *drawable;
+  GimpDrawable *drawable;
 
   BlurVals *vals;
 } BlurData;  
@@ -73,7 +74,7 @@ typedef struct {
   GimpPreviewEvent *event;
   GimpPreview *preview;
   guint event_id;
-  GDrawable *drawable;
+  GimpDrawable *drawable;
   
   gdouble scale;
   guint x;
@@ -81,7 +82,7 @@ typedef struct {
   guint width;
   guint height;
 
-  GPixelRgn *region;
+  GimpPixelRgn *region;
 
   guchar *scaled_data;
 
@@ -91,9 +92,9 @@ typedef struct {
 static void query (void);
 static void run   (gchar *name, 
 		   gint nparams, 
-		   GParam *param, 
+		   GimpParam *param, 
 		   gint *nreturn_vals,
-		   GParam **return_vals);
+		   GimpParam **return_vals);
 
 static gint blur_dialog();
 
@@ -108,7 +109,7 @@ static void close_callback (GtkWidget *widget, gpointer data);
 static gint blur_idle (gpointer data);
 
 
-GPlugInInfo PLUG_IN_INFO = {
+GimpPlugInInfo PLUG_IN_INFO = {
   NULL,    /* init_proc */
   NULL,    /* quit_proc */
   query,   /* query_proc */
@@ -134,25 +135,25 @@ MAIN ();
 static void
 query ()
 {
-  static GParamDef args_ni[] = {
-    { PARAM_INT32, "run_mode", "non-interactive" },
-    { PARAM_IMAGE, "image", "Input image (unused)" },
-    { PARAM_DRAWABLE, "drawable", "Input drawable" },
+  static GimpParamDef args_ni[] = {
+    { GIMP_PDB_INT32, "run_mode", "non-interactive" },
+    { GIMP_PDB_IMAGE, "image", "Input image (unused)" },
+    { GIMP_PDB_DRAWABLE, "drawable", "Input drawable" },
   };
   static int nargs_ni = sizeof(args_ni) / sizeof (args_ni[0]);
   
-  static GParamDef args[] = {
-    { PARAM_INT32, "run_mode", "Interactive, non-interactive" },
-    { PARAM_IMAGE, "image", "Input image (unused)" },
-    { PARAM_DRAWABLE, "drawable", "Input drawable" },
-    { PARAM_FLOAT, "blur_pct", "Randomization percentage (1 - 100)" },
-    { PARAM_FLOAT, "blur_rcount", "Repeat count(1 - 100)" },
-    { PARAM_INT32, "seed_type", "Seed type (10 = current time, 11 = seed value)" },
-    { PARAM_INT32, "blur_seed", "Seed value (used only if seed type is 11)" },
+  static GimpParamDef args[] = {
+    { GIMP_PDB_INT32, "run_mode", "Interactive, non-interactive" },
+    { GIMP_PDB_IMAGE, "image", "Input image (unused)" },
+    { GIMP_PDB_DRAWABLE, "drawable", "Input drawable" },
+    { GIMP_PDB_FLOAT, "blur_pct", "Randomization percentage (1 - 100)" },
+    { GIMP_PDB_FLOAT, "blur_rcount", "Repeat count(1 - 100)" },
+    { GIMP_PDB_INT32, "seed_type", "Seed type (10 = current time, 11 = seed value)" },
+    { GIMP_PDB_INT32, "blur_seed", "Seed value (used only if seed type is 11)" },
   };
   static int nargs = sizeof(args) / sizeof (args[0]);
   
-  static GParamDef *return_vals = NULL;
+  static GimpParamDef *return_vals = NULL;
   static int nreturn_vals = 0;
   
   const char *blurb = "Apply a 3x3 blurring convolution kernel to the specified drawable.";
@@ -167,9 +168,9 @@ query ()
 			 (char *) author,
 			 (char *) copyrights,
 			 (char *) copyright_date,
-			 "<Image>/Filters/Blur3",
+			 "<Image>/Filters/Blur/Blur3",
 			 "RGB*, GRAY*",
-			 PROC_PLUG_IN,
+			 GIMP_PLUGIN,
 			 nargs, nreturn_vals,
 			 args, return_vals);
 
@@ -181,7 +182,7 @@ query ()
 			 (char *) copyright_date,
 			 NULL,
 			 "RGB*, GRAY*",
-			 PROC_PLUG_IN,
+			 GIMP_PLUGIN,
 			 nargs_ni, nreturn_vals,
 			 args_ni, return_vals);
 
@@ -191,14 +192,14 @@ query ()
 static void 
 run (gchar *name, 
      gint nparams, 
-     GParam *param, 
+     GimpParam *param, 
      gint *nreturn_vals,
-     GParam **return_vals)
+     GimpParam **return_vals)
 {
-  GDrawable *drawable;
-  GRunModeType run_mode;
-  GStatusType status = STATUS_SUCCESS;   /* assume the best! */
-  static GParam values[1];
+  GimpDrawable *drawable;
+  GimpRunModeType run_mode;
+  GimpPDBStatusType status = GIMP_PDB_SUCCESS;   /* assume the best! */
+  static GimpParam values[1];
 
   /* Get the specified drawable, do standard initialization. */
   run_mode = param[0].data.d_int32;
@@ -206,24 +207,24 @@ run (gchar *name,
   drawable = gimp_drawable_get(param[2].data.d_drawable);
 
   /* Initial return values */
-  values[0].type = PARAM_STATUS;
-  values[0].data.d_status = STATUS_SUCCESS;
+  values[0].type = GIMP_PDB_STATUS;
+  values[0].data.d_status = GIMP_PDB_SUCCESS;
   *nreturn_vals = 1;
   *return_vals = values;
 
   /* Make sure the drawable type is appropriate. */
-  if (gimp_drawable_color (drawable->id) ||
-      gimp_drawable_gray (drawable->id))
+  if (gimp_drawable_is_rgb (drawable->id) ||
+      gimp_drawable_is_gray (drawable->id))
     {
       switch (run_mode) 
 	{
-	case RUN_INTERACTIVE:
+	case GIMP_RUN_INTERACTIVE:
 	  gimp_get_data (PLUG_IN_NAME, &blur_vals);
 	  if (!blur_dialog ()) /* return on cancel */
 	    return;
 	  break;
 
-	case RUN_NONINTERACTIVE:
+	case GIMP_RUN_NONINTERACTIVE:
 	  /* If we're not interactive (probably scripting), we
 	   *  get the parameters from the param[] array, since
 	   *  we don't use the dialog box.  Make sure all
@@ -231,7 +232,7 @@ run (gchar *name,
 	   */
 	  /*TODO*/
 	  
-	case RUN_WITH_LAST_VALS:
+	case GIMP_RUN_WITH_LAST_VALS:
 	  gimp_get_data(PLUG_IN_NAME, &blur_vals);
 	  break;
 
@@ -266,7 +267,7 @@ blur_dialog()
   GtkWidget *scale_repeat;
   GtkObject *scale_random_data;
   GtkObject *scale_repeat_data;
-  GDrawable *drawable;
+  GimpDrawable *drawable;
   gchar buffer[255];
   GimpPreview *preview;
 
@@ -550,7 +551,7 @@ blur_idle (gpointer data)
 
       for (row = 0; row < info->preview->height; row++)
         {
-          gimp_preview_draw_row (info->preview, RGBA_IMAGE, row,
+          gimp_preview_draw_row (info->preview, GIMP_RGBA_IMAGE, row,
 			         &(dest[row * info->preview->width * 4]));
         }
       gimp_preview_force_redraw (info->preview);
