@@ -155,7 +155,7 @@ gimp_plugin_window_init (GimpPluginWindow *window)
 
 GtkWidget* 
 gimp_plugin_window_new (GimpPluginWindowType type, const char* title, 
-			GDrawable *drawable)
+			GimpDrawable *drawable)
 {
   GtkWidget *widget;
   GtkWidget *vbox;
