@@ -192,7 +192,7 @@ gimp_preview_init (GimpPreview *preview)
 }
 
 GtkWidget*
-gimp_preview_new (GDrawable *drawable)
+gimp_preview_new (GimpDrawable *drawable)
 {
   GimpPreview *preview;
   GtkWidget *frame;
@@ -412,6 +412,10 @@ gimp_preview_clear_border(GimpPreview *preview)
   const gint allocation_height =
     GTK_WIDGET (preview->preview)->allocation.height;
 
+  /* If no window, we're in init stages and don't need to clear anything.  */
+  if (preview->preview->window == NULL )
+	return;
+
   if (preview->width < PREVIEW_SIZE || preview->height < PREVIEW_SIZE)
     {
       gdk_window_clear_area (preview->preview->window,
@@ -500,7 +504,7 @@ gimp_preview_recompute_sizes(GimpPreview *preview, gfloat new_scale)
 static void 
 gimp_preview_update_preview  (GimpPreview *preview)
 {
-  GPixelRgn region;
+  GimpPixelRgn region;
   const gint image_x = preview->image_x;
   const gint image_y = preview->image_y;
   const gint prev_x = preview->prev_x;
@@ -638,7 +642,7 @@ gimp_preview_update_preview  (GimpPreview *preview)
 
       for (row = 0; row < preview->height; row++) 
 	{
-	  gimp_preview_draw_row (preview, RGBA_IMAGE, row, 
+	  gimp_preview_draw_row (preview, GIMP_RGBA_IMAGE, row, 
 				 &(preview->buffer[row * preview->width * 4]));
 	}
     } 
@@ -684,7 +688,7 @@ gimp_preview_force_redraw (GimpPreview *preview)
 
  /*
    Draw one scaled row of data in the preview.
-   type is the format of the data (e.g. RGBA_IMAGE).
+   type is the format of the data (e.g. GIMP_RGBA_IMAGE).
    row is the relative number of the row within the preview.
    The top row of the preview is number 0.
    data must have a length of preview->width pixels.
@@ -695,7 +699,7 @@ gimp_preview_force_redraw (GimpPreview *preview)
    to step through source and destination!
 */
 void 
-gimp_preview_draw_row (GimpPreview *preview, GDrawableType type,
+gimp_preview_draw_row (GimpPreview *preview, GimpImageType type,
 		       const gint row, const guchar *const data)
 {
   const gint width = preview->width;
@@ -710,7 +714,7 @@ gimp_preview_draw_row (GimpPreview *preview, GDrawableType type,
   
   switch(type)
     {
-    case RGBA_IMAGE:
+    case GIMP_RGBA_IMAGE:
       {
 	guchar *dest_ptr = buf_start;
 	const guchar * src_ptr = data;
@@ -729,7 +733,7 @@ gimp_preview_draw_row (GimpPreview *preview, GDrawableType type,
 	  }
       }
       break;
-    case RGB_IMAGE:
+    case GIMP_RGB_IMAGE:
       {
 	guchar *dest_ptr = buf_start;
 	const guchar * src_ptr = data;
@@ -743,7 +747,7 @@ gimp_preview_draw_row (GimpPreview *preview, GDrawableType type,
 	  }
       }
       break;
-    case GRAYA_IMAGE:
+    case GIMP_GRAYA_IMAGE:
       {
 	guchar *dest_ptr = buf_start;
 	const guchar * src_ptr = data;
@@ -760,7 +764,7 @@ gimp_preview_draw_row (GimpPreview *preview, GDrawableType type,
 	  }
       }
       break;
-    case GRAY_IMAGE:
+    case GIMP_GRAY_IMAGE:
       {
 	guchar *dest_ptr = buf_start;
 	const guchar * src_ptr = data;
@@ -785,7 +789,7 @@ gimp_preview_draw_row (GimpPreview *preview, GDrawableType type,
 
 /*
   Draw one unscaled row of data in the preview.
-  type is the format of the data (e.g. RGBA_IMAGE).
+  type is the format of the data (e.g. GIMP_RGBA_IMAGE).
   row is the relative position of the row w.r.t. preview->image_y
   The first row of data is the row preview->image_y in the image.
   data must have a length of preview_event->width pixels.
@@ -803,7 +807,7 @@ gimp_preview_draw_row (GimpPreview *preview, GDrawableType type,
   to step through source and destination!
 */
 void 
-gimp_preview_draw_unscaled_row (GimpPreview *preview, GDrawableType type,
+gimp_preview_draw_unscaled_row (GimpPreview *preview, GimpImageType type,
 		       const gint row, const guchar *const data)
 {
   const gint width = preview->width;
@@ -829,7 +833,7 @@ gimp_preview_draw_unscaled_row (GimpPreview *preview, GDrawableType type,
   if (y_start >= y_end)
     return;
 
-  if ((type == RGBA_IMAGE) || (type == GRAYA_IMAGE))
+  if ((type == GIMP_RGBA_IMAGE) || (type == GIMP_GRAYA_IMAGE))
     {
       /* This checkerboard version must always be computed */
       const gint first_check_idx =
@@ -851,7 +855,7 @@ gimp_preview_draw_unscaled_row (GimpPreview *preview, GDrawableType type,
   
   switch(type)
     {
-    case RGBA_IMAGE:
+    case GIMP_RGBA_IMAGE:
       for (check_idx = 0; check_idx < 2; check_idx++)
 	{
 	  buf_start[check_idx] =
@@ -879,7 +883,7 @@ gimp_preview_draw_unscaled_row (GimpPreview *preview, GDrawableType type,
 	    }
 	}
       break;
-    case RGB_IMAGE:
+    case GIMP_RGB_IMAGE:
       {
 	guchar* const dest_ptr = buf_start[0];
 
@@ -894,7 +898,7 @@ gimp_preview_draw_unscaled_row (GimpPreview *preview, GDrawableType type,
 	  }
       }
       break;
-    case GRAYA_IMAGE: 
+    case GIMP_GRAYA_IMAGE: 
       for (check_idx = 0; check_idx < 2; check_idx++)
 	{
 	  buf_start[check_idx] =
@@ -920,7 +924,7 @@ gimp_preview_draw_unscaled_row (GimpPreview *preview, GDrawableType type,
 	    }
 	}
       break;
-    case GRAY_IMAGE:
+    case GIMP_GRAY_IMAGE:
       {
 	guchar* const dest_ptr = buf_start[0];
 
@@ -942,7 +946,7 @@ gimp_preview_draw_unscaled_row (GimpPreview *preview, GDrawableType type,
 
   for(y = y_start; y < y_end; y++)
     {
-      const check_idx = (y  / CHECK_SIZE) & 1;
+      const gint check_idx = (y  / CHECK_SIZE) & 1;
 
       gtk_preview_draw_row (GTK_PREVIEW (preview->preview),
 			    buf_start[check_idx],
