@@ -49,7 +49,7 @@ struct _GimpPreviewClass {
 struct _GimpPreview {
   GtkVBox parent;
 
-  GDrawable *drawable;		/* The drawable that is shown */
+  GimpDrawable *drawable;		/* The drawable that is shown */
   gint drawable_has_alpha;	/* Does the drawable have alpha */
   GtkWidget *preview;
   GtkWidget *progress_bar;
@@ -86,14 +86,14 @@ struct _GimpPreviewEvent {
 };
 
 GtkType    gimp_preview_get_type (void);
-GtkWidget* gimp_preview_new      (GDrawable *drawable);
+GtkWidget* gimp_preview_new      (GimpDrawable *drawable);
 void       gimp_preview_update   (GimpPreview *preview);
 
-void       gimp_preview_draw_row (GimpPreview *preview, GDrawableType type,
+void       gimp_preview_draw_row (GimpPreview *preview, GimpImageType type,
 				  const gint row, const guchar *const data);
 
 void       gimp_preview_draw_unscaled_row (GimpPreview *preview,
-					   GDrawableType type,
+					   GimpImageType type,
 					   const gint row,
 					   const guchar *const data);
 
